[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[libmicrohttpd] branch master updated: Applied spelling fixes.
From: |
gnunet |
Subject: |
[libmicrohttpd] branch master updated: Applied spelling fixes. |
Date: |
Tue, 21 Apr 2020 02:57:25 +0200 |
This is an automated email from the git hooks/post-receive script.
silvioprog pushed a commit to branch master
in repository libmicrohttpd.
The following commit(s) were added to refs/heads/master by this push:
new 0e12cc26 Applied spelling fixes.
0e12cc26 is described below
commit 0e12cc26791c3d38023f593f5242bdcff5e548de
Author: silvioprog <address@hidden>
AuthorDate: Mon Apr 20 21:52:22 2020 -0300
Applied spelling fixes.
---
src/microhttpd/daemon.c | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/src/microhttpd/daemon.c b/src/microhttpd/daemon.c
index 660ee61e..1c0fcb7e 100644
--- a/src/microhttpd/daemon.c
+++ b/src/microhttpd/daemon.c
@@ -5992,7 +5992,7 @@ MHD_start_daemon_va (unsigned int flags,
#endif
#endif
/* Thread pooling currently works only with internal select thread mode */
#if defined(MHD_USE_POSIX_THREADS) || defined(MHD_USE_W32_THREADS)
if ( (0 == (*pflags & MHD_USE_INTERNAL_POLLING_THREAD)) &&
(daemon->worker_pool_size > 0) )
@@ -6000,7 +6000,7 @@ MHD_start_daemon_va (unsigned int flags,
#ifdef HAVE_MESSAGES
MHD_DLOG (daemon,
_ (
- "MHD thread pooling only works with
MHD_USE_INTERNAL_POLLING_THREAD\n"));
+ "MHD thread polling only works with
MHD_USE_INTERNAL_POLLING_THREAD\n"));
#endif
goto free_and_fail;
}
@@ -6488,7 +6488,7 @@ MHD_start_daemon_va (unsigned int flags,
struct MHD_Daemon *d = &daemon->worker_pool[i];
memcpy (d, daemon, sizeof (struct MHD_Daemon));
/* Adjust pooling params for worker daemons; note that memcpy()
has already copied MHD_USE_INTERNAL_POLLING_THREAD thread mode into
the worker threads. */
d->master = daemon;
@@ -5992,7 +5992,7 @@ MHD_start_daemon_va (unsigned int flags,
#endif
#endif
- /* Thread pooling currently works only with internal select thread mode */
+ /* Thread polling currently works only with internal select thread mode */
#if defined(MHD_USE_POSIX_THREADS) || defined(MHD_USE_W32_THREADS)
if ( (0 == (*pflags & MHD_USE_INTERNAL_POLLING_THREAD)) &&
@@ -6488,7 +6488,7 @@ MHD_start_daemon_va (unsigned int flags,
struct MHD_Daemon *d = &daemon->worker_pool[i];
memcpy (d, daemon, sizeof (struct MHD_Daemon));
- /* Adjust pooling params for worker daemons; note that memcpy()
+ /* Adjust polling params for worker daemons; note that memcpy()
has already copied MHD_USE_INTERNAL_POLLING_THREAD thread mode into
the worker threads. */
--
To stop receiving notification emails like this one, please contact
address@hidden.
[Prev in Thread] |
Current Thread |
[Next in Thread] |
- [libmicrohttpd] branch master updated: Applied spelling fixes.,
gnunet <=